@@ -114,6 +114,7 @@ enum {
 #define GDM_INTERRUPT_SUSPEND     'S'
 #define GDM_INTERRUPT_SELECT_USER 'U'
 #define GDM_INTERRUPT_LOGIN_SOUND 'L'
+#define GDM_INTERRUPT_THEME       'H'
 
 /* The dreaded miscellaneous category */
 #define FIELD_SIZE 256
@@ -211,10 +212,14 @@ enum {
 #define GDM_KEY_PINGINTERVAL "xdmcp/PingIntervalSeconds=15"
 #define GDM_KEY_WILLING "xdmcp/Willing=" EXPANDED_SYSCONFDIR "/gdm/Xwilling"
 
-#define GDM_KEY_GTKRC "gui/GtkRC=" EXPANDED_DATADIR "/themes/Default/gtk/gtkrc"
+#define GDM_KEY_GTK_THEME "gui/GtkTheme=Default"
+#define GDM_KEY_GTKRC "gui/GtkRC="
 #define GDM_KEY_ICONWIDTH "gui/MaxIconWidth=128"
 #define GDM_KEY_ICONHEIGHT "gui/MaxIconHeight=128"
 
+#define GDM_KEY_ALLOW_GTK_THEME_CHANGE "gui/AllowGtkThemeChange=true"
+#define GDM_KEY_GTK_THEMES_TO_ALLOW "gui/GtkThemesToAllow=all"
+
 #define GDM_KEY_BROWSER "greeter/Browser=false"
 #define GDM_KEY_EXCLUDE "greeter/Exclude=bin,daemon,adm,lp,sync,shutdown,halt,mail,news,uucp,operator,nobody,gdm,postgres,pvm,rpm,nfsnobody,pcap"
 #define GDM_KEY_MINIMALUID "greeter/MinimalUID=100"
@@ -415,6 +420,8 @@ struct _GdmDisplay {
 
     /* Only set in the main daemon as that's the only place that cares */
     GdmLogoutAction logout_action;
+    
+    char *theme_name;
 };
 
 typedef struct _GdmXServer GdmXServer;
@@ -548,6 +555,7 @@ void		gdm_final_cleanup	(void);
 #define GDM_SOP_SOFT_RESTART_SERVERS "SOFT_RESTART_SERVERS"  /* no arguments */
 /* Suspend the machine if it is even allowed */
 #define GDM_SOP_SUSPEND_MACHINE "SUSPEND_MACHINE"  /* no arguments */
+#define GDM_SOP_CHOSEN_THEME "CHOSEN_THEME"  /* <slave pid> <theme name> */
 
 /* Notification protocol */
 /* keys */
